divide_by_area

Function divide_by_area 

pub fn divide_by_area(
    model: &mut Model,
    shape: &Shape,
    max_area: f64,
    tol: Tolerances,
) -> OgeomResult<Built>
Cut every face of shape larger than max_area in half, across its longer extent, until none is.

Errors

OgeomError::Construction if max_area is not a positive area, and as divide_face.