fix_shape

Function fix_shape 

pub fn fix_shape(
    model: &mut Model,
    shape: &Shape,
    tol: Tolerances,
) -> OgeomResult<Fixed>
Mend shape where a mend is known for what is wrong with it.

See the module documentation for what is and is not done.

Errors

OgeomError::Dangling if a handle fails to resolve; OgeomError::Construction if a rebuilt container comes out empty.