fix_small_faces

Function fix_small_faces 

pub fn fix_small_faces(
    model: &mut Model,
    shape: &Shape,
    size: f64,
    tol: Tolerances,
) -> OgeomResult<SmallFaces>
Remove every face of shape smaller than size: a spot (it fits in a ball of that diameter) collapses to a point, and a strip (two long sides within size of each other along their length, every other side shorter than size) collapses to one of its long sides.

Errors

OgeomError::Construction if size is not a distance or the rebuilt shape comes out empty.