pub fn swept_to_elementary(
model: &mut Model,
shape: &Shape,
tol: Tolerances,
) -> OgeomResult<Built>Expand description
shape with every surface of extrusion or revolution that is a plane,
drum, cone, ball or torus restated as it: a line or circle extruded, a
line or circle revolved in a plane through the axis. Every trim is
re-derived; the surfaces are the same point sets, so nothing moves.